import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::DataSync::LocationObjectStorage.
 */
export declare function getLocationObjectStorage(args: GetLocationObjectStorageArgs, opts?: pulumi.InvokeOptions): Promise<GetLocationObjectStorageResult>;
export interface GetLocationObjectStorageArgs {
    /**
     * The Amazon Resource Name (ARN) of the location that is created.
     */
    locationArn: string;
}
export interface GetLocationObjectStorageResult {
    /**
     * Optional. The access key is used if credentials are required to access the self-managed object storage server.
     */
    readonly accessKey?: string;
    /**
     * Specifies the Amazon Resource Names (ARNs) of the DataSync agents that can connect with your object storage system. If you are setting up an agentless cross-cloud transfer, you do not need to specify a value for this parameter.
     */
    readonly agentArns?: string[];
    readonly cmkSecretConfig?: outputs.datasync.LocationObjectStorageCmkSecretConfig;
    readonly customSecretConfig?: outputs.datasync.LocationObjectStorageCustomSecretConfig;
    /**
     * The Amazon Resource Name (ARN) of the location that is created.
     */
    readonly locationArn?: string;
    /**
     * The URL of the object storage location that was described.
     */
    readonly locationUri?: string;
    readonly managedSecretConfig?: outputs.datasync.LocationObjectStorageManagedSecretConfig;
    /**
     * X.509 PEM content containing a certificate authority or chain to trust.
     */
    readonly serverCertificate?: string;
    /**
     * The port that your self-managed server accepts inbound network traffic on.
     */
    readonly serverPort?: number;
    /**
     * The protocol that the object storage server uses to communicate.
     */
    readonly serverProtocol?: enums.datasync.LocationObjectStorageServerProtocol;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource Type definition for AWS::DataSync::LocationObjectStorage.
 */
export declare function getLocationObjectStorageOutput(args: GetLocationObjectStorageOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetLocationObjectStorageResult>;
export interface GetLocationObjectStorageOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the location that is created.
     */
    locationArn: pulumi.Input<string>;
}
